@@ -15,7 +15,7 @@
 use algorona::lower_bound;
 
 #[test]
-fn test_functor() {
+fn test_lower_bound() {
     assert_eq!(lower_bound(vec![1, 1, 1, 3], 0), 0);
     assert_eq!(lower_bound(vec![1, 1, 1, 3], 1), 0);
     assert_eq!(lower_bound(vec![1, 1, 1, 3], 2), 3);
